@@ -16,7 +16,7 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 import aeidon
-import imp
+import importlib
 
 from aeidon.i18n   import _, d_
 from unittest.mock import patch
@@ -46,10 +46,10 @@ class TestModule(aeidon.TestCase):
 
     @patch.dict("os.environ", dict(LANGUAGE="sr@Latn"))
     def test_get_system_modifier__latn(self):
-        imp.reload(aeidon.locales)
+        importlib.reload(aeidon.locales)
         assert aeidon.locales.get_system_modifier() == "Latn"
 
     @patch.dict("os.environ", dict(LANGUAGE="en"))
     def test_get_system_modifier__none(self):
-        imp.reload(aeidon.locales)
+        importlib.reload(aeidon.locales)
         assert aeidon.locales.get_system_modifier() is None
